copy_directory_recursive

Function copy_directory_recursive 

async fn copy_directory_recursive(
    source: &PathBuf,
    target: &PathBuf,
    overwrite: bool,
) -> Result<(), CommonError>
Recursively copy a directory tree from source into target. Iterative (uses an explicit stack of (SrcDir, DstDir)) so it can’t blow the Tokio task stack on very deep trees. Files inside re-use tokio::fs::copy for fast path; directories are created with create_dir. Symlinks are dereferenced.